egJofF.1dec93.data <- list(
  input = stats::ts(matrix(c(0, 0.25999999046325861, 
	1.8399999141693133, 0.53000009059906183, 0.12999999523163019, 
	-0.12999999523163019, 0.26999998092650834, -0.80000007152557018, 
	-0.78999996185302912, -0.51999998092651722, 0.51999998092651722, 
	-3.1299999952316284, -0.50999999046325684, 0.25000000000000089, 
	0.7799999713897714, -0.51999998092651545, 0.12999999523162842, 
	0.38999998569488703, 0.90999996662139715, 0.39000010490417303, 
	-0.13000011444091619, 0.53000009059906006, 0, -0.39999997615814387, 0, 
	1.049999952316286, -0.25999999046326039, -0.52999997138976696, 0, 
	0.13999998569488525, 0, 0.12999999523162842, -0.39999997615814387, 
	-0.39000010490417125, -0.51999998092651367, 0, -0.38999998569488703, 0, 
	-0.12999999523162664
	, -0.51999998092651545, -0.12999999523162842, 0.25999999046325684, 
	0.25999999046325684, -0.25999999046325684, 0.25999999046325684, 0, 
	-0.27999997138977317, 0, 0.049999952316288621, 0.57000005245208651, 
	0.4700000286102286, 0.049999952316285956, -0.049999952316285956, 
	0.30999994277954279, 0.47000002861022949, 0.30999994277954102, 
	0.62999999523163019, 0.62999999523162842, 0.11000001430511119, 
	0.32000005245209096, -0.11000001430512363, 0.3199999332428014, 
	-0.10999989509581809, -0.050000071525580836, 0, 0.39999997615813854, 
	0.30000007152558084, 0.14999997615814209, 2.6499999761581403, 
	-0.94999992847442094, 0.50000000000000178, -0.25, 0, 1.2999999523162789,
	0.20000004768372115, -3.4500000476837211, -0.50000000000000178, 
	-0.89999997615813854, 0.049999952316280627, 0.25, 1.4500000476837194, 
	1.1499999761581385, 4.2500000000000036, -0.50000000000000355, 
	-0.099999904632571912, -0.15000009536742809, 0.5, 1.5, 
	0.20000004768372293, 2.0499999523162806, 0.95000004768371937, 
	-2.6000001430511475, -0.79999995231629129, -3.3999999761581403, 0.25, 
	-0.75, 0.10000002384185791, 1.1500000953674263, -0.65000009536742454, 
	0.10000002384185791, 1.4499999284744227, -1.3999999761581403, 
	-1.4499999284744209, -1.1000000238418632, -1.6499999761581385, -0.5, 
	-0.70000004768372115, -0.20000004768371937, -0.54999995231628063, 
	-0.20000004768371582, 0, 0.050000071525575507, -0.050000071525575507, 
	0.050000071525575507, 0, -0.050000071525575507, 0, 0.20000004768371582, 
	0.35000002384185969, -0.050000071525575507, 0.04999995231628418, 0.75, 
	0.15000009536743342, 0.74999999999999822, 0.59999990463256836, 
	0.85000002384186324, -0.69999992847442982, -0.10000002384185969, 
	-0.55000007152557373, -0.89999997615813854, -0.69999992847442982, 
	-0.45000004768371582, 1.7499999999999947, -0.60000002384184903, 
	-0.85000002384186146, -0.19999992847442449, -0.14999997615814387, 
	-0.35000002384185613, -0.10000002384185969, -0.14999997615814031, 
	-0.24999999999999822, 0.35000002384185436, 0.39999997615814387, 
	1.3500000238418579, 0.84999990463256658, -0.84999990463256658, 
	-1.7500000000000018, -0.45000004768371582, 0.10000002384186146, 
	-0.10000002384186146, -0.10000002384185791, -0.049999952316282403, 
	0.10000002384185613, -0.15000009536743164, 0, -0.8999999165534982, 
	-0.050000011920926291, -0.50000000000000089, 1.2500000000000009, 
	0.14999997615814031, 0.14999997615814209, 0.75, -0.049999952316282403, 
	0.39999997615814031, -1.0499999523162842, 0.19999992847442627, 
	0.2000000476837176, -0.24999999999999822, -0.10000002384186146, 
	0.10000002384186146, 0.35000002384185436, 0.099999904632568359, 
	0.20000004768371582, 0.20000004768371582, 0.64999997615814209, 
	0.35000002384185969, -0.10000002384185969, 0.60000002384185791, 
	0.099999904632568359, 0.30000007152557373, 0.29999995231628773, 
	0.64999997615813854, 0.20000004768371582, -0.12999999523162487, 
	-0.16999995708465754, 0, 0.049999952316278851, 0.019999980926519001, 
	-0.0099999904632603887, 0.029999971389770508, 0.0099999904632586123, 
	0.25000000000000711, 0.85000002384185613, -0.03999996185302912, 
	0.28999996185302912, 0.26999998092650834, -0.24000000953673961, 
	-0.25999999046326039, -0.51999998092650834, -0.42999994754791793, 
	0.03999996185302912, -0.34000003337860285, -0.49000000953673961, 
	-1.0099999904632604, -0.71999990940093994, -0.15000009536743164, 
	-0.34999990463256836, -0.56000006198883057, -0.16999993801116986, 
	-0.0099999999999997868, -0.15000000000000036, -0.12000022888183537, 
	-0.49999977111816385, -0.41999999999999993, -0.020000000000000462, 
	-0.49000000000000021, 0.29999999999999982, -0.019999999999999574, 
	-0.55999999999999961, -0.5600000000000005, -0.46999999999999975, 
	-0.37999999999999989, -0.44000000000000039, 3.120000000000001, 
	-1.7000000000000011, 2, -1.0999999999999996, -0.58000000000000007, 
	-0.58999999999999986, -0.58000000000000007, 0.020000000000000462, 
	-0.55000000000000071, -0.35999999999999943, -0.44000000000000039, 
	0.52999999999999936, 0.11000000000000032), 236, 1),
  start=c(1974,2), frequency=12),

  output=stats::ts(matrix(c(
	1.0362694300518098, 1.025641025641022, 1.0152284263959355, 
	1.5075376884422147, 1.2376237623762376, 0.48899755501223191, 
	0.97323600973235658, 0.96385542168674354, 0.71599045346063073, 
	1.1848341232227488, 0.93676814988290058, 0.69605568445474975, 
	0.69124423963134629, 0.45766590389015038, 0.45558086560365113, 
	0.68027210884353095, 1.1261261261261262, 1.1135857461024499, 
	1.1013215859030838, 0.43572984749455956, 0.65075921908893086, 
	0.86206896551723833, 0.42735042735043344, 0.85106382978723105, 
	0.2109704641350241, 0.63157894736841502, 0.62761506276151524, 
	0.41580041580040694, 0.41407867494824607, 0.41237113402062442, 
	0.4106776180698064, 0.6134969325153462, 0.60975609756096982, 
	0.40404040404040981, 0.4024144869215206, 1.0020040080160322, 
	0.79365079365079083, 0.78740157480316086, 0.58593749999999445, 
	0.58252427184465472, 0.57915057915058743, 0.57581573896352622, 
	0.57251908396947382, 0.56925996204933049, 0.75471698113207275, 
	0.37453183520599787, 0.74626865671641529, 0.37037037037037562, 
	0.55350553505534528, 0.73394495412843774, 0.18214936247723393, 
	0.90909090909090906, 0.54054054054053546, 1.0752688172043037, 
	0.35460992907801925, 0, 1.0600706713780943, 0.69930069930069683, 
	0.52083333333332837, 0.86355785837651122, 0.85616438356164382, 
	1.0186757215619719, 0.84033613445378152, 0.83333333333333337, 
	0.33057851239669889, 0.82372322899505768, 0.49019607843136787, 
	0.97560975609756329, 0.64412238325281568, 0.80000000000000004, 
	0.79365079365079361, 0.78740157480314965, 0.78125, 0.77519379844961245, 
	0.76923076923076927, 1.0687022900763403, 1.057401812688826, 
	0.59790732436471072, 1.1887072808320909, 0.88105726872247958, 
	0.87336244541483887, 1.1544011544011503, 0.85592011412269409, 
	1.4144271570014144, 0.83682008368200045, 1.1065006915629283, 
	0.95759233926128984, 0.81300813008131245, 1.3440860215053763, 
	0.79575596816975369, 0.92105263157895112, 0.78226857887874091, 
	1.0349288486416524, 0.64020486555697831, 0.76335877862596513, 
	0.75757575757575035, 1.1278195488721876, 0.99132589838909191, 
	0.61349693251533743, 1.3414634146341393, 0.84235860409145957, 
	0.47732696897375382, 0.59382422802850354, 0.59031877213695394, 
	0.58685446009389675, 0.70011668611434574, 0.34762456546928988, 
	-0.11547344110853848, 0.23121387283237324, 0.80738177623991103, 0, 
	0.22883295194506706, 1.0273972602739792, 0.45197740112994994, 
	0.56242969628796402, 0.11185682326621288, 0.44692737430168233, 
	0.11123470522802481, 0.55555555555555558, 0.6629834254143584, 
	0.32930845225028693, 0, 0.32822757111597062, 0.10905125408941582, 
	0.43572984749455956, 0.43383947939261547, 0.10799136069115392, 
	0.21574973031284017, 0, 0.75349838536059055, 0.3205128205128327, 
	0.53248136315228967, 0.31779661016948851, 0.21119324181626487, 
	0.42149631190726178, 0.10493179433369205, 0.62893081761005687, 
	0.20833333333333628, 0.20790020790021085, 0.3112033195020717, 
	0.1034126163391875, 0.51652892561983477, 0.71942446043165764, 
	0.40816326530612823, 0.20325203252031362, 0.3042596348884497, 
	0.10111223458037848, 0.30303030303030015, 0.20140986908358796, 
	0.70351758793970132, 0.29940119760478756, 0.19900497512438095, 
	0.39721946375371547, 0.59347181008902927, 0.39331366764994247, 
	0.19588638589618301, 0.29325513196480663, 0.48732943469785578, 
	0.38797284190107245, 0.28985507246376535, 0.38535645472062208, 
	0.76775431861803944, 0.09523809523808982, 0.19029495718363734, 
	0.18993352326685931, 0.47393364928909953, 0.28301886792452563, 
	0.18814675446848811, 0.28169014084506777, 0.46816479400749067, 
	0.37278657968313672, 0.37140204271122701, 0.18501387604070568, 
	0.55401662049862288, 0.36730945821854127, 0.18298261665142071, 
	0.27397260273972346, 0.45537340619307831, 0.27198549410697836, 
	0.36166365280289847, 0.63063063063063318, 0.44762757385854968, 
	0.44563279857397503, 0.79858030168588412, 0.44014084507042256, 
	0.43821209465381245, 0.26178010471205182, 0.4351610095735422, 
	0.25996533795493687, 0.25929127052722312, 0.34482758620690146, 
	0.6013745704467256, 0.51238257899232154, 0.33984706881902416, 
	0.16934801016088302, 0.25359256128486657, 0.42158516020236092, 
	0.25188916876575262, 0.25125628140703277, 0.58479532163742931, 
	0.74750830564783344, 0.41220115416323166, 0.2463054187192095, 
	2.4570024570024569, -0.079936051159068197, 0.32000000000000456, 
	0.23923444976076327, 0.23866348448687125, 0.3968253968253968, 
	-0.079051383399204991, 0.23734177215189647, 0.15785319652723193, 
	-0.23640661938535174, 0.15797788309636876, -0.078864353312298352, 
	0.15785319652723193, 0.1576044129235529, 0.23603461841070919, 
	0.3139717425431644, -0.078247261345848446, 0.15661707126076965, 
	0.078186082877243407, 0.23437500000000888, 0.077942322681211457, 
	0.15576323987538054, 0.31104199066874472, 0.31007751937984934, 
	0.15455950540957389, 0.3086419753086464, -0.076923076923072556, 
	0.23094688221707693, -0.15360983102917716, 0.076923076923072556, 
	0.076863950807067122, 0.15360983102919898, 0.3834355828220859, 
	0.41658231520992256, 0.27895362324804157, -1.232578786225196, 
	1.0751176334310617, -0.24185364218939195, -0.088007301722119916, 
	0.36629583495498486, -0.3488095377301666, 0.44247759544885956, 
	-0.3951241290944999, 0.1764729004574955, -0.44472445848453296, 
	0.4163878827947573, -1.0037018806946758, 1.1458687716946758, 
	-0.031643838950871347, 0.66830427671729753, 1.0539141928954276, 
	-0.13229647216661736, 0.66715202282398955, -0.28022429074313343, 
	0.96123197438119634, 1.8689961374427924, -0.49306751000153753, 
	0.51014426011964009, 1.1185320875256595, 1.1238962850789105, 
	0.51732137835237901, -0.34582359067060903, 0.27339297753792702, 
	0.3603115519516763, -0.098315419963572834, -0.22837947172392006, 
	0.88847045072205666, 0.23974001992018068, 0.69153508488180582, 
	0.0060792795679259874, 0.22757019052340136, -0.15749158645968028, 
	0.45433384857706549, 0.44477014620468636, 0.0011983780808693038, 
	0.4744379032172894, -0.3117503884100839, 0.48202085841929193, 
	0.12329369073100863, 0.055667258166671819, -0.074709968262413107, 
	1.0069880558761299, -0.42315023179055228, 1.4248949032659532, 
	-0.56158985257191252, 0.63310576107537575, -0.31807083449968554, 
	0.44268451728574637, 1.4386320360522518, -0.27236442146530881, 
	0.72811525163567459, 0.62074508989221167, -0.10269315501477699, 
	-0.0039496351186499943, 0.73352490722049501, -0.43010469685608638, 
	0.63285283845138329, 0.54766065570255063, 0.46715979903998328, 
	0.36952249956088501, 0.13688110403677348, 0.073283609946411338, 
	-0.16046748983526865, 0.18743810632026903, 0.16337843932053558, 
	-0.78962507948251781, 0.58181827832426047, 0.089262673954029953, 
	-0.49621426712898498, -0.24032334895924617, 0.87610249780435656, 
	-0.044097328991874511, 0.93279999873576713, 1.4864996397590182, 
	0.46185231525264869, 0.49159424266280255, 0.67501364519340179, 
	0.43500875583195076, -0.0049874193606195298, 1.3978821555089542, 
	-0.63920955639403332, 0.10608682868139506, -0.30193838498805592, 
	-1.4347241832318396, 1.1793552217623038, -0.68621212764445172, 
	-0.43105868640670564, -0.099352721212854309, -1.0385323181869244, 
	0.27278370944732905, -0.59500136328320186, -0.97908677859053261, 
	0.14211908168007803, -0.85737965228549651, -0.65693419172945378, 
	0.41728134433801645, 0.13229488116328766, -1.4281990427396496, 
	0.78604380764136439, 0.21141369731404328, 1.0513315143160473, 
	0.15392459443127049, 0.65107033200939479, 0.70512530139505025, 
	0.77629605868204243, 1.5573893419793556, -0.51198092113872307, 
	0.87809798700107011, 0.81027218939649492, -0.76635171604401076, 
	0.64702284691552925, 1.0293866552539024, 0.38160098736056286, 
	-0.097463761101287433, 0.79805932225425646, 1.0424071566959414, 
	0.6911086062217654, 0.38736307502270384, 0.29541780722689182, 
	0.58759858841396295, -0.34712684454683768, 0.90524227093179355, 
	0.31523964413928962, -0.24772777667598495, 0.6649630055792588, 
	0.60915466848359645, 0.6711722047238674, -0.84401386944479972, 
	1.032229483806314, 0.099599075801474563, 0.34409451349700593, 
	0.55688153660866924, 0.45841876923160668, 1.1319841929890362, 
	0.78546800213920309, 0.1310132259806997, 0.64242527803329486, 
	-0.084032427564760731, -1.0861680521646648, 1.0419834341969465, 
	-0.63106834704254611, 0.065707489898337079, 0.60525781082583996, 
	-0.32700866423968777, 0.21423291374036479, -0.13260940662759246, 
	-0.25756092898067162, 1.0531805836218517, 0.69732015587621832, 
	1.0314335314983847, 0.30842246000843904, 0.086651216591265609, 
	0.26624115081860578, 0.76984979000784726, 0.67304863440624552, 
	0.34550536631049777, 0.59665109724713028, 0.39900166897871081, 
	0.44895641038364437, 0.080514479010704562, 0.33459528136243238, 
	0.071086339413182181, 1.2651155143189197, -0.093565175886010737, 
	0.5674294051423926, 0.24711359063843327, -0.20468455653299794, 
	0.16171730013891236, 0.4894945077743722, -0.0030444383152511689, 
	0.2038827649906379, 0.89972986976402591, 0.099989231315339655, 
	0.38836119703064553, -0.15411641246520708, 0.19849811638465337, 
	0.0027770785490716719, -0.16987314459112984, 0.0081266162578071208, 
	0.41923177332198547, 0.54750804009611287, -0.40981671096656919, 
	0.33494026417840583, 0.25877518853804421, 0.022351881466673964, 
	-0.15301137059856895, 0.085925453916112698, -0.44509648145641612, 
	-0.16264148723797253, 0.11749429333202356, -0.0047787733994423516, 
	-0.32637422467114474, -0.70354558444409399, 0.11113811414782207, 
	-0.57538319017681505, 0.048110818459239015, -1.1930554172478027, 
	0.27669969555936025, 0.0090394630194867032, 0.73758990874607533, 
	0.55544983969997275, -0.046710502676871116, -0.021408999768337777, 
	-0.11118284484259752, 0.11930563560146892, 0.16004975863705204, 
	0.14892570286531348, -0.41650330373120842, 0.31866785359794775, 
	-0.12128595401019997, 0.074536258746785058, 0.14000784490616058, 
	0.012824240203599407, 0.047467497507152991, 0.03749426839209756, 
	0.3330845262413209, 0.12566931600637832, 0.2679943672269382, 
	-0.04888149269661124, 0.39446402746132903, 0.19518756468035126, 
	0.49079973936638216, 0.60742942840566749, 0.06858723888760436, 
	0.028814079289205454, 0.57302924990061166, -0.15399714162468495, 
	0.15585838478677702, 0.39752195808465196, 0.41310740792607353, 
	1.1784394393696267, 3.6044107512060646, 1.7162243065256315, 
	-2.6616964227323145, -0.55092717011554815, -0.10809350087827196, 
	0.45313134045718922, -0.16158351848111493, 0.54622698765932842, 
	0.45606975184438747, 2.4903191347309388, 2.8923197185851084, 
	3.0199430199430197, -0.14134709931170109, 0.90467105668041115, 
	1.1405220785557453, 1.1397214014352046, 1.8006200810875268, 
	0.83167389012533677, 1.3185408921933086, 5.624032563205871, 
	-1.0584020842379505, -2.1120193098908331, 0.76776507509527014, 
	-0.76191535509704689, 0.33064335350818203, 0.43568117075350499, 
	0.81752961459318174, 0.4468225948808473, 0.74139161952880439, 
	0.13628434365460096, 0.39740867766345472, 0.8296280229909988, 
	-0.21511158913686476, 1.2287793047696038, 0.62822765266464353, 
	1.9099518543992382, 0.46204963139860866, 0.96635832773500074, 
	1.4279864878697921, -0.17156986425796034, 0.54086842238285393, 
	0.85470085470085466, 0.55832502492522429, 1.2492563950029745, 
	1.762632197414806, 0.58698999230177062, 0.30613221084856024, 
	0.033381020505484027, 0.71983601086904703, 1.1643316925407043, 
	1.1930382707962945, 0.73050071663044991, 0.77110203332262361, 
	1.0612616716010022, 2.0731927167838471, 1.2363122571529495, 
	-1.9234124214933705, -0.38244318939831901, 1.1785188161242801, 
	-1.2309728656518861, 1.4026623782721344, 2.2555066079295156, 
	1.5121488885059453, 0.39468658490005515, 0.60872505918160302, 
	0.55042016806722693, 0.2340061008733442, -0.11256097052570142, 
	-2.48330550918197, 3.0986518296597474, 0.27813524845365106, 
	0.61268421924159633, -1.0533245556287032, -0.32435129740518964, 
	0.062578222778473094, 2.2930998540754639, 1.398002853067047, 
	1.9937293994694254, 2.3330968708126281, 1.6329045675113749, 
	-2.4478969306555647, -0.12041640770663596, -0.11278341694863935, 
	0.80984270362871824, 1.2127298007106442, -0.6372586430588415, 
	-1.6552094934521435, 4.1393314589190879, -3.4723263836808029, 
	-2.2647812912749732, -0.56838507094875146, -1.690917812599936, 
	5.7699345342170538, -0.52667999384900677, -1.646376811594189, 
	-0.67979095445793547, 0.71213799651843646, 1.6695474544311755, 
	-0.25501333024226264, -0.66240557815223711, -2.0940570893776322, 
	1.4019994423865854, 0.47134608586354532, 0.50822940693537666, 
	3.8857987475203237, 0.46053616893814586, 1.9417837575938279, 
	0.36560397777127818, 0.83054057992131725, 0.14450867052023122, 
	1.8145743145743014, 1.6653084363817006, 0.51929041926601027, 
	0.7801123361764094, -1.1490693914060743, 0.70998503462918483, 
	0.35594567508725855, 0.010330578512409221, 0.62665702578933424, 
	0.63644140290846873, 0.69361803406889821, -0.39169339861559094, 
	-0.20000677989083146, -0.78804347826086951, -1.2154204327581484, 
	0.50947908363080563, 0.91379310344830111, -0.5774816333504309, 
	0.48116579598570253, 1.1629497879326982, -0.54436029212875292, 
	1.1388747237803716, -0.39663865546219712, 1.5928725701943847, 
	0.41190539463195475, 0.34405187243613988, 2.0044837135698397, 
	0.51066580478344004, 0.69779407035823415, 0.74085901325242332, 
	1.8290170222208366, -1.7307931764413012, -1.0073492143943235, 
	0.27839999999999998, -1.9210517918115966, 1.6625996421018383, 
	1.0625360046085899, 1.4250427512825385, 0.33096040964156365, 
	1.6400074687247153, 0.83892103732280088, 2.2589949901320785, 
	0.73636390629175452, 0.70150617502284318, 2.7074491438606763, 
	-0.49301795383300084, 4.0352836727095687, 0.9855200132136761, 
	0.78780939919310866, -0.86008709057961219, 0.22097940253717091, 
	0.48726045296167247, 0.72870107002573481, 0.39802065404475045, 
	-1.1036108432444016, 0.80715059588299021, 0.20151539577623731, 
	0.45316815488161316, 0.54188244087341841, 1.3168724279835391, 
	1.0350881790309479, 1.9374416433239963, 0.47579065211307026, 
	0.30387439858191945, -0.93410754859883871, 0.24209989806320081, 
	0.9406381085547223, 0.93187256013096587, 0.18215845290081098, 
	0.51061074026103415, -0.28994126830718908, 1.2178148921363954, 
	-0.65805627854441884, 0.21503781699540264, 0.94216302873350599, 
	-0.40315684022772252, 0.92978754722535695, -1.7938309715369096, 
	1.0692275326089646, -0.44079833476184643, 1.4905915631533637, 
	-3.7589976006398294, 1.304457315537648, -0.77060753703887841, 
	-0.10020542111328223, -2.6957219519534581, 1.72151637759967, 
	-0.38509285298066936, 1.0961621607874055, 0.3471698113207547, 
	0.81227436823104693, 0.06714413607878246, 0.2833072392455081, 
	1.1845463782122767, 0.96495309936077978, 0.17465130382049726, 
	0.089594885827057658, 1.2894953307204722, -0.56607829555497169, 
	0.79029546000480422, -2.9671822493386402, 3.3968659429188977, 
	-0.21616742285673562, 1.2379183926105795, 1.2956779382025114, 
	-0.46196346077953432, 0.32184336956014742, -0.7834294216105635, 
	1.2910330607558753, 0.54129077029840389, 1.1296705319344744, 
	0.92594699124104196, 0.74387989720932335, 0.68021122348518748, 
	-0.75340030224908883, 1.4085137828335983, 3.7406704058649471, 
	-2.3882503192848019, 4.4615988486196523, 0.34026386105544421, 
	2.3508852227099672, -0.34351688111063683, -1.4685485844823367, 
	-0.59617454665893843, -0.0099999904632559478, 0.45000004768371316, 
	0.61999988555908381, 0.10000002384185969, 0.55000007152557373, 
	0.16999995708465399, 0.21000003814697266, -0.17000007629394531, 
	-0.46999990940093994, -0.33000004291534424, -0.10000002384185613, 
	-0.47000002861023127, -0.12999999523162842, 0.30000007152557373, 
	0.56999993324279785, -0.32999992370605291, 0.16999995708465399, 
	0.46000003814697266, 0.049999952316287732, 0.33000004291533891, 
	-0.38999998569488348, 0.25000000000000178, -0.090000033378601074, 
	-0.2000000476837176, -0.019999980926513672, 0.12000000476837513, 
	-0.049999952316287732, -0.019999980926513672, 0.029999971389772284, 
	0.019999980926513672, -0.12999999523163019, -0.080000042915342462, 
	-0.069999933242799628, -0.26999998092651545, -0.35000002384185613, 
	0.049999952316285956, 0.10000002384185791, 0.21000003814697088, 
	0.019999980926515448, -0.080000042915344238, -0.049999952316285956, 
	-0.019999980926511896, -0.12999999523163019, 0.03999996185302912, 
	0.090000033378601074, 0.039999961853027344, 0.029999971389770508, 
	0.28999996185302557, 0.090000033378602851, 0.019999980926511896, 
	0.05000007152557373, 0.0099999904632550596, 0, -0.06000006198882879, 
	-0.0099999904632550596, -0.0099999904632568359, 0.33000004291534069, 
	0.059999942779544568, 0.13999998569488525, 0.14000010490417125, 
	0.14999997615814387, -0.06000006198882879, -0.25000000000000178, 
	0.019999980926515448, 0.050000071525568401, 0.1100000143051183, 
	0.30999994277954102, 0.23000001907348988, 0.77999997138976873, 
	-0.21999990940093994, 0.37999999523163019, 0.80999994277954102, 
	0.77999997138977051, 0.54000008106231867, -1.4400000572204608, 
	-0.59000003337860107, -0.12999999523163019, 1.0300000905990618, 
	0.079999923706051135, 0.58000004291534779, 0.24000000953674139, 
	-0.21000003814697088, -0.34000003337859752, 0.29000008106230801, 
	0.41999995708466287, 0.10000002384185613, 1.5900000333786029, 
	-0.11000001430512008, 0.069999933242801404, 2.0399999618530309, 
	-0.29999995231629129, 0.89000010490417836, -1.0000000000000036, 
	-2.3400000333785957, 0.94999992847442272, 0.67000007629395242, 
	-0.93000006675720392, 0.049999952316280627, -0.30999994277954279, 
	-0.029999971389768731, 1.3099999427795375, -0.40999996662139893, 
	-1.6599999666213989, -0.48000001907348278, -0.85000002384185613, 
	-0.45000004768372115, -0.48999989032745184, 0.58999991416930975, 
	-0.48000001907348988, -0.099999904632559478, -0.52000010013581033, 
	0.12000000476836803, 0.25999999046326039, 0.47000002861022949, 
	0.31000006198883234, -0.58000004291534069, -0.029999971389772284, 
	0.069999933242792522, 0.22000002861022772, -0.1000000238418508, 
	0.48000001907348455, 0.6599999666214007, 0.25, 0.62000000476837336, 
	-0.12000000476837158, -0.39999997615814209, -0.51999998092651012, 
	-0.25999999046325861, -0.45000004768372115, -0.37000000476837513, 
	-0.14999997615813676, -0.27999997138977051, 0.91999995708465043, 
	-0.37000000476836981, -0.42999994754791082, -0.74000000953673961, 
	0.12000000476837158, 0.029999971389768731, -0.12000000476836981, 
	0.16999995708464688, -0.24000000953673783, -0.37999999523163019, 
	-0.27999997138977051, 0.42999994754791082, -0.52999997138976696, 
	-0.41999995708465399, -0.22000002861022949, 0.20000004768371404, 
	-0.10000002384185791, -0.06000006198882879, -0.19999992847442627, 
	0.28999996185302557, 0.080000042915347791, -0.26999998092651722, 
	-0.030000090599060059, -0.28999996185302734, 0.15999996662139893, 
	-0.12000000476837158, 0.84000003337860285, 0.10000002384185613, 
	-0.13999998569488348, 0.44999992847442805, 0.2100000381469691, 
	0.70000004768371937, -0.93000006675720925, 0.29000008106232222, 
	-0.16000008583069203, -0.60000002384185613, -0.12999999523162664, 
	0.520000100135805, 0.22999989986419855, 0.020000100135801446, -0.25, 
	0.28999996185302734, 0.23000001907348278, -0.19000005722046254, 
	-0.32999992370604758, 0.18999993801116766, 0.039999961853030896, 
	-0.1799999475479197, 0.37000000476836981, -0.060000061988830566, 
	-0.29999995231628063, -0.34000003337860107, -0.25, 0.019999980926513672,
	0, 0.29000008106231867, -0.37000000476837158, 0.25999999046325506, 
	-0.11000001430511475, 0.35000002384186146, 0.60000002384185791, 
	0.2699999809265119, 0.62999999523162842, -0.68000006675719682, 
	-0.13999998569489236, 0.060000061988830566, 0.049999952316280627, 
	0.71000003814697799, -0.38999998569488881, -0.45000004768371049, 
	-0.18999993801116943, -0.29000008106232045, -0.32999992370605291, 
	-0.0099999904632586123, 0.029999971389772284, 0, 0.45000003337859873, 
	-0.1899999999999995, -0.19999999999999929, -0.38000008583068912, 
	-0.46999991416931053, 0.059999999999998721, -0.20999999999999908, 
	-0.050000000000000711, 0.050000000000000711, 0.3100000000000005, 
	0.22999999999999865, -0.33999999999999986, -0.29999999999999893, 
	-0.66000000000000192, -0.019999999999999574, 0.33999999999999986, 
	-0.19999999999999929, 0.33000000000000007, -0.12000000000000099, 
	0.13000000000000078, -0.48000000000000043, 0.080000000000000071, 0, 
	-0.14999999999999858, -0.16000000000000014, -0.17000000000000082, 
	-0.38999999999999968, 0.14999999999999947, 45.339996337890852, 
	-26.899993896484602, -114.96000671386741, -68.179992675780795, 
	-22.5100021362299, 47.730003356933025, -137.08000946044899, 
	-72.689994812011832, 48.519996643066406, -45.30999755859375, 
	-14.980003356933707, 144.18000030517589, 26.730003356933935, 
	-16.730003356933935, 18.930000305175668, 22.169998168944858, 
	24.589996337891534, -3.6199951171881821, -12.770004272461392, 
	-62.529991149901662, -45.440002441406136, 49.879997253417969, 
	-27.26999664306652, 85.889991760253679, 34.95001220703125, 
	-20.29000854492142, 20.930007934570312, 0.89999389648392025, 
	-20.369995117187045, -5.4799957275390625, -1.7700042724609375, -19.5, 
	-39.250000000000341, -69.450004577636378, 91.419998168944403, 
	-14.919998168944517, 12.319999694823764, 13.190002441407159, 
	-27.319999694824787, -13.599998474121094, 50.05000305175804, 
	2.2899932861325851, -30.229995727538835, -3.2300033569339348, 
	-29.540000915527344, 46.950004577637287, 42.109992980956804, 
	-61.149993896484602, 7.2399978637698723, 57.579994201660043, 
	18.240005493163835, 47.259994506836165, -2.5999908447267899, 
	67.629989624023438, 38.420013427734375, 52.44999694824196, 
	-68.820007324218068, 53.96000671386696, 39.199996948242188, 
	46.399993896483693, 29.960006713868324, 81.009994506834801, 
	17.940002441407159, 35.360000610351562, 98.74000549316338, 
	-60.309997558592841, 137.19999694824173, 56.589996337889943, 
	-172.61999511718636, 120.34999084472565, 113.55000305175804, 
	214.5299987792971, 164.87998962402412, -394.99998474121116, 
	72.34999084472588, 101.80000305175759, 89.620010375977245, 
	136.02999877929642, 20.6300048828125, 42.02999877929733, 
	-19.890014648438409, 162.0800170898442, -133.52999877929733, 
	-42.040008544921875, -47.140014648436591, 153.5599975585942, 
	-26.649993896485284, 64.790008544921875, -10.08999633789108, 
	-107.23001098632812, -77.190002441405795, -293.28999328613281, 
	-40.800003051758267, 169.47000122070403, -57.849990844727017, 
	-167.33000183105491, -115.5700073242183, -83.509994506835483, 
	-39.66000366210983, -24.49000549316429, -156.87998962402321, 
	45.099990844725653, 201.42001342773551, -11.31001281738304, 
	172.02999877929688, 64.27000427246071, 119.77000427246139, 
	73.389999389648438, 58.899993896483466, 65.690002441406705, 184.75, 
	79.83999633789017, 26.320007324219659, 30.64999389648392, 
	5.4700012207035797, 16.489990234375909, -138.50000000000045, 
	179.81002807617142, 11.459991455077216, -83.470001220703125, 
	-49.050018310545511, -37.730010986329034, -58.75997924804642, 
	-93.58999633789108, -8.8100280761714203, -80.949981689453125, 
	248.8200073242183, 3.8399963378901703, -39.390014648437045, 
	15.27999877929733, 31.79000854492233, 194.72000122070312, 
	-0.070007324219659495, 17.830017089845114, 22.499999999999545, 101, 
	-23.809997558594659, 66.0999755859375, 41.380004882812955, 
	-187.72998046875045, 42.589996337891534, 182.33999633789017, 
	43.419982910155795, -57.639984130859375, 12.869995117188864, 
	191.42999267578125, 31.630004882811136, 43.079986572265625, 
	-36.469970703125, -150.17001342773347, 92.869995117187045, 
	-48.899993896483466, 59.589996337889261, 7.9100036621098297, 
	19.3800048828125, 282.6699829101558, 150.0800170898442, 
	240.53997802734375, -22.729980468750455, -31.5, 54.94998168945358, 
	290.16000366210892, -36.75, -91.229980468750455, -883.10000610351426, 
	-40.92999267578125, 181.70999145507767, -102.8300170898442, 
	147.61001586914199, 108.95999145507722, 25.980010986328125, 
	-90.550018310546875, 192.26000976562409, -64.749999999999545, 
	-90.910003662108011, -2.1099853515634095, 111.8099975585933, 
	-100.83999633788972, 95.309997558592841, 226.64999389648347, 
	-44.519989013671875, 6.0999755859388642, 49.630004882811591, 
	79.589996337890625, 53.470001220704489, 209.84002685546784, 
	39.429992675782159, -67.16000366210983, -24.39999389648483, 
	24.14999389648483, 27.019989013672784, -265.36999511718932, 
	-17.72000122070267, -47.16000366210892, -298.6300048828125, 
	241.0800170898433, -38.059997558593295, 17.190002441404886, 
	-214.86999511718705, -186.8800048828125, -78.110015869138806, 69.75, 
	105.74002075195176, 16.149993896485284, 189.47000122070131, 
	33.299987792969659, -26.859985351561136, 77.289978027341476, 
	-80.279975585936427, 73.819999999999709, -21.75, -130.00999999999976, 
	127.88000000000011, -67.25, 63.849999999999909, 83.759999999999764, 
	-14.179999999999836, -169.80000000000018, -56.579999999999927, 
	32.369999999999891, -0.23000000000001819, 55.720000000000255, -40.5, 
	-105.03999999999996, 38.239999999999782, -53.289999999999964, 
	67.610000000000127, -44.970000000000255, 146.22000000000025, 150.75, 
	186.9699999999998, 93.269999999999982, 83.690000000000055, 
	0.86000000000012733, 170.32000000000016, -146.94000000000005, 
	0.30006668148477439, 0.11080332409972299, 0.68622025456557834, 
	-0.39573485764537758, 0.28694404591104733, 0.60526026191262239, 
	0.5578647998249836, -0.21755683672359405, 0.33794832661070534, 
	0.2607561929595828, 0.24924143909839619, -1.1242027888876878, 
	0.31704383951022191, -0.14167393199651265, 0.61115355233002289, 
	0.35795639440286364, 0.5728491137051448, -0.13970983342289092, 
	-0.16142918639690057, 0.67909884660989539, 0.22483940042826553, 
	0.53413096891357759, 0.51004144086707048, -0.17972301511787717, 
	0.095318788392289772, 0.19045603639826472, 0.052803886366036543, 
	-0.6755330377876293, 0.53134962805526031, 0.3699788583509514, 
	0.094786729857819899, -0.010521885521885523, -0.1157529201304851, 
	0.25284450063211122, 0.063051702395964693, 0.2205419029615627, 
	0.052394425233155191, -0.062840385421030584, 0.42967931251309999, 
	0.69915475320880727, -0.10362694300518134, 0.093360995850622408, 
	0.40418696237952118, 0.27869529314616021, 0.22645393721049922, 
	0.15405155592071479, 0.14356029532403611, -0.13311488838828589, 
	0.73823438941864039, 0.41730279898218831, 0.34461787958645856, 
	0.46464646464646464, 0.38206314096119043, 0.65104166666666663, 0, 
	0.079609911433973529, 0.3977329223426469, 0.2971179558284639, 
	0.61222474572923868, 0.32387869270782216, 0.12717667775386421, 
	0.34196384953590619, 0.14605647517039921, 0.38891589693728729, 
	0.12590799031476999, 0.78351712130005802, 0.31672905269219692, 
	0.15308075009567546, 0.7260221627818112, 0.47420333839150225, 
	-0.0094393052671323391, 0.34928726517511566, 0.065851364063969894, 
	-0.028203440819780014, 0.235094978371262, -0.59104981705600901, 
	0.71725179312948284, 0.037481259370314844, 0.046834020232296741, 
	0.8894298286677278, 0.30623608017817372, 0.42557128318993431, 
	0.17503454629203133, 0.52418613205812026, 0.74101180129905775, 
	-0.26334907373774064, 0.40061913866885185, 0.027205949034188808, 
	0.26291931097008159, -0.24414504023871961, 0.25380710659898476, 
	-0.41591320072332733, -0.22698383875068096, -0.081900081900081897, 
	-0.7103825136612022, -0.26600623738763529, -0.4690517796376345, 
	-0.24949177601182776, -0.60213061602593798, -0.47530288909599255, 
	-0.66485625994943343, -0.41478129713423834, -0.72889057175312377, 
	0.10489177076380281, -0.12383311106877501, -0.33381020505484027, 
	0.09569377990430622, 0.28680688336520077, 0.23832221163012393, 
	0.26628625772705661, 0.45527838376173763, 0.43433103578510057, 
	0.44185390617655351, 0.30887308124298013, 0.24260520668097416, 
	0.52126966396723451, -0.2500231502916937, 0.17638321574452284, 
	0.3058103975535168, -0.32335550628233556, 0.54685327648530913, 
	-0.24889380530973451, 0.16634322151372333, 0.11993726358520158, 
	0.5252488020641356, 0.84334036116967637, -0.0181801654395055, 
	0.063642149286298758, 0.13628929674722878, 0.19054532256601034, 
	0.22640825937330195, -0.53311647239540982, 0.36337209302325579, 
	0.24438812454742939, 0.70428893905191869, 0.55590424101138702, 
	-0.17833259028087384, 0.50915587315765964, 0.23107003199431211, 
	0.14186912573151267, 0.23906499026031522, 0.75081706563024464, 
	0.0438365772400491, 0.75365875032863028, -0.086979211968339562, 
	-0.06964394532950291, 0.57496297586897815, -0.60632308358596798, 
	0.61873638344226578, -0.57162653732894508, 0.47038327526132406, 
	0.25143055314721691, 0.025944824007610483, 0.1815666609026457, 
	0.25028048675239495, 0.16356749311294766, 0.31800601633003867, 
	0.3427004797806717, 0.51229508196721307, 0.33129459734964323, 
	0.5418677504021675, -0.17684210526315788, 0.36274675215117258, 
	0.50432882239219967, 0.45161829890440747, 0.12488552160519524, 
	0.69017129552635959, 0.14039144438021306, 0.49480455220188024, 
	0.11488593467914, 0.040983606557377046, 0.47521507578861122, 
	-0.25279295441572208, 0.17985611510791366, -0.040803003101028239, 
	0.081639317495305744, 0.040786361040867934, 0.53816046966731901, 
	0.24330900243309003, 0.69579288025889963, -0.24104129840912744, 
	0.32216494845360827, -0.5057803468208093, 0.54062777374324211, 
	0.35313001605136435, -0.26391554702495201, 0.60139523694972341, 
	-0.27100271002710025, -0.063938618925831206, 0.40786948176583493, 
	-0.079649542015133412, 0.52610601833399762, 0.13480294980572516, 
	-0.031675641431738996, 0.30893536121673004, -0.4738213693437574, 
	-0.023803856224708403, 0.047619047619047616, -0.34904013961605584, 0, 
	-0.43782837127845886, -0.3278164228032302, -0.42515642547729826, 
	-0.49947635543381941, -0.4534045826248887, 0.11386742578283855, 
	0.36558615647087495, 0.14570179698882954, -0.20206918849013902, 
	0.080991333927269787, -0.072833211944646759, 0.048590864917395532, 
	0.064756354217257575, -0.28312570781426954, -0.29204185933317106, 
	-0.081360344967862666, -0.13028255028092176, -0.34243783122706889, 
	-0.40906487768960159, 0.35324077877269366, 0.13916175507531106, 
	-0.17166680291016104, 0.09007533573534228, 0.089994273091712346, 
	0.089913356220369459, 0.13066557778685178, 0.39964113856944783, 
	0.073111291632818848, 0.073057878074519036, 0.38935756002595717, 
	-0.34744667097608273, -0.0081083272520878942, 0.80278949075575734, 
	-0.34590941999839114, -0.088795608653535682, 0.35549810131695886, 
	-1.4837604146845782, -0.48019329743554828, -0.48696848028632084, 
	-0.53039178787897123, 0.44314258232897752, 1.0018438509789342, 
	0.37906658121668119, 0.66016541085297575, -0.33321809799574165, 
	0.42589203408895893, 0.095223763738483749, 0.67356755078808495, 
	0.58251551936099211, -0.024986632355348849, 1.0788690720024856, 
	1.6874042805720377, -0.17322028779148679, 0.42355298814456765, 
	0.44495045223901425, -0.87759629972414088, -0.11874909389084011, 
	-1.1000213074826446, 0.011125433753675853, -0.73554291271191785, 
	-1.2581266089179448, -0.79600686321945746, -0.25021982326197034, 
	-0.33694925295613282, -0.65601619164511282, -0.14677663979376515, 
	1.3533009325609984, -1.0510591223077874, -0.23917906652775842, 
	1.3462271733516813, 3.3472229494116652, -0.76843464684132323, 
	1.6792134166848474, 2.2592417947477319, -0.00018616435213561581, 
	-0.24231194645010598, 0.8525372555933376, 0.33265263357512104, 
	1.3097428214177154, -0.15247316112722228, 2.376199367260754, 
	0.95365506843765246, -1.0821287889516895, 0.35400835128281233, 
	1.0939566886743728, 1.1179477986951556, 1.4179449278132068, 
	-1.987821365575295, 0.24456453959723196, 0.2577464817549035, 
	1.4035223801326666, 2.2807845612586313, 1.4053926412745883, 
	-0.8390943745922631, 0.5727139117237311, 0.87819944069238642, 
	0.4721828702463256, -1.8049498948082194, -2.3463129662652285, 
	0.81104703618300256, 1.4402702723579468, -0.75271114354223723, 
	0.61176779999081121, -0.45609606151757515, 0.86062519562212336, 
	0.3729870900804888, -0.85273152042044875, -0.48866413526253105, 
	-0.67483106328026121, 1.4775789653885674, 1.0675910933417376, 
	-1.0567156264806408, -1.8380501520144652, 0.033853088765155248, 
	0.625929951594691, 0.47408552510799767, 0.38007344484612532, 
	1.4543413966819199, 0.90538942196664129, -0.50452595863645011, 
	0.67246666795157084, -0.62720383724689688, -0.037030738731518485, 
	0.85025200476847573, 0.25609156394684157, 0.61915070814412099, 
	0.95104439872644675, -1.8210913419428962, 0.17172499936934843, 
	-1.2776346344450744, -0.19247830582186615, 0.61643892140485423, 
	1.8127078415376905, 0.52434051005530846, 0.35699320351330416, 
	0.74852846310422194, 3.3516980810022083, -0.42277532398549966, 
	-1.9493009766411318, -0.83933828352519901, -0.38438699892420913, 
	-0.30290026195808556, 0.97668390403721261, -0.78750024396718199, 
	-0.091986818529781272, -0.090389035354202812, 0.48600307541688392, 
	-0.27306023133080803, 0.2741406757303983, 0.019551835316859421, 
	0.1008989782021131, -0.099639213582128933, -0.043758644505336924, 
	0.39322579140295127, 0.81917971258478406, 0.11858450386361113, 
	-0.030135532356979678, 1.7696174372411222, 0.73806049504674587, 
	1.1634623168832627, 0.7361810708653258, 1.5456367118619851, 
	-1.5551060589328647, 0.84091777931195233, 0.33635042001314336, 
	-0.18643586064476397, 0.29196064451052606, 0.27938276072711654, 
	2.2022352239222456, 2.2489965366372293, -1.3389829937921731, 
	0.78893554391359322, -0.60757254064791777, -1.0874703164506554, 
	0.3612995106936534, 0.95133487377470816, -0.27128618845374119, 
	0.73121872659766951, 1.335982643255802, 0.83677909827369779, 
	-0.2191328284397793, -0.1852517163772785, -0.95487670912070166, 
	-0.87783254345820161, 1.0445915727726198, -0.65646621568164842, 
	0.55974255522954852, -0.089179983664136167, 0.089228407702283616, 
	-0.16253307036330525, -0.45111047437314727, -1.4118679307872868, 
	-1.943224138999313, -1.0998970938576305, -0.021969667150090116, 
	1.6885879514448356, -0.19721197199560597, -0.95150458178614672, 
	-0.018268635099421129, -0.7763048948186505, -0.43988440200349876, 
	0.50513824845080002, -0.65926614350395674, -1.6932665981335473, 
	-1.3533857148314437, -1.4865387994866177, -1.1166206634812417, 
	0.14186187529170569, -1.5738465811591076, -0.8251999515702485, 
	1.4046974225068438, 0.18010037845385082, -1.7333351117895703, 
	1.0065091044488632, -1.7546646367374077, -0.38389219398211422, 
	-0.20383706177380023, 0.52909236910051605, -0.56186382944078572, 
	0.34705433273716552, 0.47371494388789892, -0.79609454069443097, 
	-1.1310776168464354, 0.61992415327346151, -0.66577681132459987, 
	-0.44466421172001847, -0.71685203719824664, 0.87762194245142577, 
	2.1450219466045732, -1.392981632674287, -1.3530206324793692, 
	0.920491235813655, -0.14932278625426221, -1.3630218826419369, 
	-1.0712223163383334, 1.1989775204437607, 0.14296373118091063, 
	0.28335254313546254, -0.26245641165777112, -0.35712527013921508, 
	-0.11372439838670663, 0.19877173850097174, -0.30909804675056629, 
	-0.31805693706516935, -0.51371780663825684, 0.47106436227256682, 
	-0.38114902340131074, -0.693419076801015, -0.78333483057145192, 
	0.2154443327319143, 1.3637610255412296, 0.93670692233199615, 
	2.2527660410730133, 0.85425470658828384, -0.42630081276469406, 
	0.96689857048337158, -0.26331891005834884, -0.34664680035880208, 
	-0.072354870699497129, 2.6376785341907123, 1.8614762465033934, 
	1.8418395447034912, 0.37608216572854652, 0.37882614405496939, 
	-1.3936832217917161, -1.0224118856352269, 1.2138266748959783, 
	0.64064976228210146, 0.67185911322323311, 0.24214452290217908, 
	2.1102689849903533, 0.94746034056177886, 6.7203625151416508, 
	0.18238108261754615, 1.2099594544623884, -1.6798502413113472, 
	-2.5224442816064059, 2.4282720947239009, 0.32082271249011163, 
	-2.9696177503598542, 1.5480407797803621, -0.055410641047093284, 
	-2.6967542564980107, -1.3864669602330748, -0.16529325138739939, 
	-1.0211845486748494, 0.70049835672204142, 2.4876572829496952, 
	0.52704822171654442, 2.0182031355835415, 2.4304622225606676, 
	2.3713190941747966, -1.9919247060614445, -1.9362666625870175, 
	1.4740209177956645, -2.5251683607136046, 0.38259201274563481, 
	-0.31957818834220164, 0.8045486660690353, -0.25291542900922515, 
	1.800325693893825, 1.0346463480227042, -1.4640432283249172, 
	-0.16578763850890021, -2.4362619558417409, -0.51983222404923835, 
	0.20114790541720962, 1.1836448732672824, 2.1990855644615337, 
	-0.27326865657512567, -0.67521609911830605, 0.071396803821821564, 
	0.11583871964445665, 0.33373427001052675, 1.7006101424278781, 
	-0.25143726664332194, -3.1929736912806601, 2.6117350780503545, 
	2.2216170830780402, 2.3565162375079387, 0.11407646800961316, 
	0.2456713464628848, 1.2766481719576896, 2.4676375169966458, 
	-0.69196825192031064, -0.19704446971162104, 1.0919819731451614, 
	0.82971798963696863, 3.110425708368477, -0.17393309122420691, 
	-1.0564637648350774, 3.3931556315473834, 4.6128898860568146, 
	1.4004131759899068, 1.239779909379406, 1.3316666696386061, 
	2.8131825674890667, 1.0169638508574732, 2.3685495655500404, 
	3.4018772300796716, 1.1028950127041639, -0.063619509419962125, 
	2.1381155528189293, 6.3567462988756773, 2.4565196977640671, 
	-4.4978783368944795, -3.8056380129088883, 1.9076733969766759, 
	3.1805057975502251, 4.030557885245023, -0.37165193378773986, 
	-0.82529864827411026, 1.0333031462453313, 0.16713064694584942, 
	-0.77449700112205111, 2.8570578816005177, 2.5063484532659537, 
	0.54478904807321038, 0.19105401560946544, 0.33705413580164867, 
	-0.9922414529615573, 0.30365181959577636, -1.9910415980190828, 
	-1.1948295950417305, -1.6044133148235409, 0.11200294710654728, 
	0.13426730986555593, -1.0071020516270919, -0.59313784191851371, 
	-1.8713274242587561, 0.37175071545519722, -0.077270494650964985, 
	-0.026011672606444124, -1.185763480789259, -0.65569984983077778, 
	-0.027924183242402961, -0.88603750927625857, 0.8162775003621634, 
	0.045950175004806963, 2.4773699598605856, -0.93975098637908305, 
	-0.41620179978233124, 1.777770043571089, 1.8599174351134842, 
	0.51734150441903914, -1.7814033523000963, -2.2791524751457306, 
	-1.0985197841466579, -0.52189025215156148, 0.2039681252791205, 
	0.53053683556746922, 1.8301794747553537, 0.79937289486155005, 
	1.4834170270008333, -0.78793748689045617, -1.4309470817222405, 
	-1.1661871504763877, -2.2714012795010423, 0.30455486179979208, 
	-2.1382216132583101, -0.92628710223761834, -1.0142249026279493, 
	-1.5935728375516365, -0.78449258756282403, 0.70213243058442198, 
	-0.1739530007401521, 0.54817758503264458, -0.43429247597587733, 
	-0.73919024267816957, -1.3363807873358766, -1.7056444458993079, 
	-0.0045353885420446154, 0.099120674314984974, 1.0203069698198211, 
	-1.8002766899036935, -4.4138731389130728, -6.5044566873572753, 
	1.4988166091472017, 0.2385454762360496, 0.6153083659255747, 
	-3.336196988412476, -0.7181636266487863, 3.0951995029310857, 
	1.752967144008228, -1.3133891088382839, 1.627157413183614, 
	-0.22961908687972607, 2.7231060479253393, 1.7207826175206868, 
	0.73760347037790619, 0.6725682851977578, 2.6256531474311164, 
	2.4911974866257909, 1.2803304152974375, 0.17210655538427425, 
	-0.43455007353924319, -0.20633890546894085, -1.0817231660887687, 
	1.5907244239511289, 2.5694677917038242, -0.31929745705265611, 
	4.9530635896139019, 3.4154427584677887, 2.4258813308584988, 
	3.5118666489737618, -5.2350909460069266, -1.6146628985129954, 
	-2.27725085131897, 1.3170228900481988, 1.620423049252125, 
	4.3732151442889453, 3.2382129564690603, -0.55923385328947528, 
	0.50135040343457893, -1.046331994847822, -1.5820890279564825, 
	-2.7948052123872582, 0.00083881132521902073, -0.58596810201379501, 
	-0.87850126725435596, 0.55294383407316416, -1.2142257658581332, 
	0.56637173006566666, -0.50022127104034364, -0.29049216830528862, 
	0.60197799018986231, -1.3421091695315421, 0.68779626966368457, 
	-0.4016954528677984, 1.1226601274764358, 6.212016726366504, 
	3.970987515781784, -0.85199383718941546, -4.4907486620281736, 
	-5.0105485232067508, -1.7557673038973223, -3.6809150427408386, 
	-0.021231928023507058, -0.20386636790023896, -0.51833828560539108, 
	1.2131259658278679, -2.3857387485590049, -2.9220077972726575, 
	-0.97612001582678487, 0.99370981758152999, -0.26377692902734573, 
	-2.175145796084005, 1.1328418282102279, 3.3226124250337188, 
	0.8757401587323157, -0.75454698927336517, 1.3121596385977543, 
	1.3441780211164842, -0.52648123708841077, -0.24076452314903427, 
	1.8925733547885821, -3.2249930830120901, -1.007544455264012, 
	1.8382082848402228, 1.8263826941881502, 6.5041077005209305, 
	4.1382721367003992, -6.5682624925655198, -6.5586584116263298, 
	-2.4910889750408338, -1.6797136881084098, 3.4959342857589992, 
	0.95776348168822256, -0.41095890410958941, 0.41265474552957399, 
	-0.13698630136986314, 1.2345679012345689, 0.27100271002710052, 
	-0.54054054054054101, -0.27173913043478287, 0.40871934604904669, 
	-0.67842605156038049, -2.868852459016396, -4.2194092827004104, 
	-2.6431718061674032, -1.5082956259426861, -1.8376722817764182, 
	0.93603744149766077, -0.30911901081916565, 1.2403100775193809, 
	0.61255742725880602, 1.8264840182648416, 1.0463378176382669, 
	0.44378698224852109, 1.0309278350515472, 0.72886297376091735, 
	1.1577424023154859, 1.7167381974248943, -0.28129395218002839, 
	0.4231311706629059, 1.1235955056179785, 0.13888888888888901, 
	0.55478502080443881, 0.55172413793103503, 0.27434842249657088, 
	0.41039671682626577, 1.6348773841961868, 0.80428954423592569, 
	0.39893617021276628, 0.52980132450331174, 0.92226613965744486, 
	1.4360313315926905, 0.77220077220077288, 0.76628352490421525, 0, 
	0.12674271229404319, 0.50632911392405111, 0, 0.12594458438287165, 
	-0.50314465408805076, -0.3792667509481672, 0.25380710659898498, 
	1.2658227848101276, 2.499999999999988, 0.36585365853658569, 
	0.97205346294046269, 0.2406738868832734, 0.36014405762304957, 
	0.59808612440191444, 0.47562425683709914, 0.82840236686390611, 
	0.23474178403755891, -0.35128805620608933, 0.82256169212691022, 
	0.34965034965034997, -1.0452961672473877, 1.1737089201877946, 
	-0.1160092807424595, -0.58072009291521542, -0.35046728971962648, 
	0.23446658851113739, 0.58479532163742742, -0.34883720930232592, 
	-0.11668611435239216, 0.35046728971962648, 0.34924330616996541, 0, 
	-1.9721577726218116, -2.3668639053254461, -1.2121212121212133, 
	-0.36809815950918917, 1.4778325123152585, 1.3349514563106808, 
	0.59880239520958145, 1.7857142857142874, 0.46783625730994194, 
	-0.81490104772991923, 0.23474178403755891, 0.35128805620608933, 
	-0.81680280046674525, 0.70588235294117707, 0.58411214953271084, 
	1.1614401858304308, -0.2296211251435134, -0.4602991944764101, 
	-0.8092485549132955, -1.1655011655011664, -0.82547169811320831, 
	-2.0214030915576715, 2.1844660194174779, -0.5938242280285041, 
	-0.5973715651135012, -0.60096153846153899, -0.36275695284159648, 
	-0.48543689320388395, -0.48780487804878098, -0.73529411764704589, 
	-0.86419753086419826, -0.37359900373599036, -0.87500000000000078, 
	1.8915510718789423, -0.12376237623762386, 0.74349442379180841, 
	1.2300123001230023, 1.0935601458080204, 0.60096153846153899, 
	1.9115890083632037, 1.4067995310668242, 1.618497109826591, 
	0.79635949943117246, 0.22573363431151261, 0.45045045045045085, 
	2.0179372197309435, -0.10989010989010999, 1.1001100110011011, 
	0.54406964091403742, 0.6493506493506499, 0.53763440860215095, 
	0.42780748663100454, 0.10649627263045804, -0.10638297872340435, 
	-0.74547390841319439, 0.10729613733905588, -0.53590568060021482, 
	0.3232758620689658, 0.75187969924810905, 0.31982942430703654, 
	0.42507970244420867, 0.21164021164021185, -0.31678986272439313, 
	-0.31779661016949184, 0.42507970244420867, 0.52910052910052963, 
	-0.84210526315789558, 0.42462845010615752, 1.0570824524312907, 
	0.52301255230125576, -0.62434963579604641, -0.94240837696335167, 
	0.21141649048625813, -0.10548523206751065, -0.42238648363252418, 
	0.5302226935312836, 0.10548523206751065, 0.1053740779768178, 
	0.63157894736842168, 0.73221757322175796, 0.51921079958463179, 
	-0.30991735537190113, 1.4507772020725402, 0.30643513789581234, 
	0.6109979633401228, 0.60728744939271306, 0.90543259557343025, 
	0.29910269192423866, 0.29821073558647032, -0.19821605550049573, 
	1.3902681231380352, 0.097943192948101082, 0.58708414872798487, 
	0.38910505836575909, 0.19379844961240328, 0, 0.87040618955511573, 
	-0.28763183125598196, 0, 0.57692307692307743, 0.57361376673040199, 
	-0.47528517110267254, 0.28653295128940914, 0.57142857142857195, 
	0.66287878787877796, 0.28222013170273885, -0.3752345215759853, 
	0.84745762711863437, 0, -0.37348272642390323, -0.28116213683222979, 
	-1.0338345864661767, 0.47483380816715248, -0.37807183364839353, 
	-0.37950664136622425, 0.38095238095238126, 0.66413662239088189, 
	-0.56550424128181009, 0.56872037914691997, 0.28275212064091554, 
	-0.6578947368421163, 0.75685903500473106, 0.18779342723004713, 
	-0.18744142455482679, 0.28169014084508109, 0, -0.46816479400750144, 
	-1.222953904045146, -0.47619047619048716, -0.095693779904295687, 
	-1.1494252873563229, -0.67829457364342216, 0.097560975609767023, 
	0.6822612085769878, 1.0648596321394115, 0.095785440613016262, 
	0.095693779904316933, 0.6692160611854584, -0.18993352326685678, 
	-0.095147478591806847, -0.28571428571429652, -0.19102196752626571, 
	0.76555023923445054, 0.28490028490029573, 0.66287878787877796, 
	0.37629350893697117, -0.65604498594188332, 0.75471698113207608, 
	-0.18726591760299641, -0.3752345215759853, 1.2241054613935876, 
	0.83720930232559254, 0.46125461254611561, 0.36730945821854949, 
	0.54894784995425483, 0.18198362147406749, 0.2724795640327079, 
	-0.18115942028985521, 0.27223230490017164, 0.27149321266969356, 
	0.090252707581217492, 0.450856627592436, 1.0683760683760575, 
	1.0570824524312907, 0.62761506276150691, 1.0395010395010404, 
	0.82304526748971274, 0.61224489795918424, 1.2170385395537537, 
	1.4028056112224461, 0.79051383399209552, 0.98039215686274594, 
	0.77669902912621425, 0.77071290944123383, 0.57361376673040199, 
	0.38022813688212959, 0.37878787878787912, 0.18867924528301902, 
	0.75329566854990648, 0.93457943925233722, 0.37037037037037068, 
	0.73800738007380129, 0.54945054945054994, 0.72859744990892594, 
	0.54249547920434038, 0.3597122302158276, 0.17921146953405032, 
	0.17889087656529531, 0.17857142857142871, 0.53475935828875065, 
	0.53191489361702182, 0.52910052910052963, 0.52631578947368474, 
	0.52356020942408432, 0.52083333333333381, 0.34542314335060481, 
	0.51635111876075779, 0.5136986301369868, 1.0221465076660998, 
	0.5059021922428335, 0.67114093959731602, 0.33333333333333365, 
	0.49833887043189412, 0.49586776859504178, 0.49342105263157937, 
	0.32733224222585955, 0.48939641109298576, 0.6493506493506499, 
	0.48387096774193594, 0.64205457463884485, 0.47846889952153154, 
	0.63492063492063544, 0.78864353312302904, 0.93896713615023553, 
	0.77519379844961311, 0.76923076923076994, 0.61068702290076393, 
	0.91047040971168514, 0.90225563909774509, 0.59612518628912126, 
	0.59259259259259311, 0.88365243004418337, 1.0218978102189626, 
	1.0115606936416195, 1.0014306151645218, 1.133144475920681, 
	1.1204481792717098, 1.1080332409972309, 0.95890410958904193, 
	0.94979647218453278, 1.0752688172043021, 1.0638297872340434, 
	1.1842105263157905, 1.4304291287386228, 1.282051282051283, 
	1.3924050632911404, 0.99875156054931424, 0.98887515451173003, 
	0.97919216646266927, 0.12121212121212133, 0.72639225181598133, 
	0.84134615384615463, 0.95351609058402953, 1.0625737898465182, 
	0.93457943925233733, 0.92592592592592671, 0.91743119266055129, 
	0.68181818181818243, 0.56433408577878152, 0.673400673400674, 
	0.89186176142697959, 1.1049723756906087, 0.76502732240437221, 
	0.97613882863340651, 0.32223415682062323, 0.42826552462525613, 
	0.31982942430703654, 0.31880977683315653, 0.31779661016949184, 0, 
	0.31678986272439313, 0.94736842105263241, 1.1470281543274254, 
	0.5154639175257737, 0.20512820512820532, 0, 0.40941658137154591, 
	-0.1019367991845057, -0.30612244897959212, 0.20470829068577295, 
	0.10214504596527078, 0.10204081632653071, 0.71355759429153987, 
	0.40485829959514208, 0.20161290322580663, 0.40241448692152954, 
	0.30060120240479876, 0.29970029970031109, 0.3984063745019924, 
	0.29761904761903685, 0.29673590504452169, 0.69033530571991075, 
	0.48971596474046192, 0.29239766081870289, 0.38872691933916459, 
	0.19361084220716379, 0.1932367149758456, 0.38572806171649027, 
	0.28818443804035676, 0.28735632183907006, 0.38204393505253142, 
	0.19029495718363482, 0.18993352326685678, 0.18957345971563999, 
	0.5676442762535483, 0.47036688617122441, 0.18726591760299641, 
	0.18691588785046745, 0.27985074626864659, 0.18604651162790714, 
	0.18570102135561764, 0.18535681186283612, 0.37002775208140642, 
	0.46082949308756826, 0.45871559633026543, 0.36529680365296835, 
	-0.18198362147406749, -0.54694621695533319, -0.36663611365719556, 
	0.27598896044159282, 0.36697247706422048, 0.091407678244962501, 
	0.091324200913252232, 0.36496350364963531, 0.18181818181818196, 
	0.1814882032667878, 0.36231884057971042, 0.6317689530685825, 
	0.35874439461883439, 0.35746201966041141, 0.44523597506677592, 
	0.26595744680852074, 0.44208664898319128, 0.26408450704226355, 
	0.43898156277435413, 0.34965034965034997, 0.26132404181185659, 
	0.34752389226759373, 0.17316017316017332, 0.3457216940363011, 
	0.08613264427216967, 0.34423407917383853, 0.51457975986277926, 
	0.34129692832764535, 0.42517006802722074, 0.42337002540219248, 
	0.337268128161889, 0.50420168067226934, 0.33444816053511739, 
	0.33333333333333365, 0.33222591362126275, 0.49668874172185479, 
	0.32948929159802337, 0.4926108374384241, 0.73529411764706853, 
	0.48661800486618045, 0.16142050040355138, 0.40290088638194144, 0, 
	0.16051364365971121, 0.56089743589742747, 0.31872509960159395, 
	0.3177124702144562, 1.0292953285827493, 0.47021943573667752, 
	0.46801872074883039, 0.23291925465837668, 0.15491866769945792, 
	0.46403712296983801, 0.53887605850655251, 0.7656967840735075, 
	0.68389057750759097, 0.67924528301887688, 0.29985007496251898, 
	0.22421524663676318, 0.59656972408650311, 0.14825796886582668, 
	-0.074019245003692807, 0.29629629629629656, 0.29542097488921737, 
	0.14727540500736389, 0.22058823529410967, 0.22010271460015507, 
	0.29282576866764298, 0.21897810218977309, 0.36416605972322602, 
	0.21770682148041465, 0.28964518464880545, 0.21660649819493802, 
	0.36023054755044059, 0.28715003589375476, 0.14316392269148187, 
	0.21443888491779067, 0.28530670470756092, 0.21337126600285305, 
	0.1419446415897801, 0.42523033309709463, 0.21171489061396553, 
	0.14084507042253536, 0.49226441631505752, 0.34989503149054535, 
	0.13947001394700154, 0.41782729805013968, 0.1386962552011097, 0, 
	0.069252077562334619, 0.27681660899654004, 0), 236, 10),
   start=c(1974,2), frequency=12)
    )

class(egJofF.1dec93.data) <- "TSdata"
attr(egJofF.1dec93.data$input,  "seriesNames") <- "R90"
attr(egJofF.1dec93.data$output, "seriesNames") <- c("CPI", "GDP", "M1", "RL", "TSE300", "employment", "PFX", "commod.price index", "US ind.prod.",  "US CPI")

